@@ -31,7 +31,6 @@ func NewRootCmd() *cobra.Command {
 			if indent, err = getIndent(cmd.Flags()); err != nil {
 				return err
 			}
-
 			if len(args) == 0 {
 				fileInfo, _ := os.Stdin.Stat()
 
@@ -48,27 +47,43 @@ func NewRootCmd() *cobra.Command {
 			}
 
 			xPathQuery, singleNode := getXpathQuery(cmd.Flags())
-			cssQuery, _ := cmd.Flags().GetString("query")
-			nodeContent, _ := cmd.Flags().GetBool("node")
+			withTags, _ := cmd.Flags().GetBool("node")
 			colors := getColorMode(cmd.Flags())
 
+			options := utils.QueryOptions{
+				WithTags: withTags,
+				Indent:   indent,
+				Colors:   colors,
+			}
+
+			cssQuery, _ := cmd.Flags().GetString("query")
+			cssAttr, _ := cmd.Flags().GetString("attr")
+			if cssAttr != "" && cssQuery == "" {
+				return errors.New("query option (-q) is missed for attribute selection")
+			}
+
 			pr, pw := io.Pipe()
 
 			go func() {
 				defer pw.Close()
 
 				if xPathQuery != "" {
-					err = utils.XPathQuery(reader, pw, xPathQuery, singleNode, nodeContent, indent, colors)
+					err = utils.XPathQuery(reader, pw, xPathQuery, singleNode, options)
 				} else if cssQuery != "" {
-					err = utils.CSSQuery(reader, pw, cssQuery)
+					err = utils.CSSQuery(reader, pw, cssQuery, cssAttr, options)
 				} else {
-					var isHtmlFormatter bool
-					isHtmlFormatter, reader = isHTMLFormatterNeeded(cmd.Flags(), reader)
+					var contentType utils.ContentType
+					contentType, reader = detectFormat(cmd.Flags(), reader)
 
-					if isHtmlFormatter {
+					switch contentType {
+					case utils.ContentHtml:
 						err = utils.FormatHtml(reader, pw, indent, colors)
-					} else {
+					case utils.ContentXml:
 						err = utils.FormatXml(reader, pw, indent, colors)
+					case utils.ContentJson:
+						err = utils.FormatJson(reader, pw, indent, colors)
+					default:
+						err = fmt.Errorf("unknown content type: %v", contentType)
 					}
 				}
 
@@ -104,6 +119,8 @@ func InitFlags(cmd *cobra.Command) {
 	cmd.PersistentFlags().BoolP("html", "m", viper.GetBool("html"), "Use HTML formatter")
 	cmd.PersistentFlags().StringP("query", "q", "",
 		"Extract the node(s) using CSS selector")
+	cmd.PersistentFlags().StringP("attr", "a", "",
+		"Extract an attribute value instead of node content for provided CSS query")
 	cmd.PersistentFlags().BoolP("node", "n", viper.GetBool("node"),
 		"Return the node content instead of text")
 }
@@ -186,18 +203,27 @@ func getColorMode(flags *pflag.FlagSet) int {
 	return colors
 }
 
-func isHTMLFormatterNeeded(flags *pflag.FlagSet, origReader io.Reader) (bool, io.Reader) {
+func detectFormat(flags *pflag.FlagSet, origReader io.Reader) (utils.ContentType, io.Reader) {
 	isHtmlFormatter, _ := flags.GetBool("html")
 	if isHtmlFormatter {
-		return isHtmlFormatter, origReader
+		return utils.ContentHtml, origReader
 	}
 
 	buf := make([]byte, 10)
 	length, err := origReader.Read(buf)
 	if err != nil {
-		return false, origReader
+		return utils.ContentText, origReader
 	}
 
 	reader := io.MultiReader(bytes.NewReader(buf[:length]), origReader)
-	return utils.IsHTML(string(buf)), reader
+
+	if utils.IsJSON(string(buf)) {
+		return utils.ContentJson, reader
+	}
+
+	if utils.IsHTML(string(buf)) {
+		return utils.ContentHtml, reader
+	}
+
+	return utils.ContentXml, reader
 }
