@@ -2,6 +2,7 @@ package utils
 
 import (
 	"bytes"
+	"encoding/json"
 	"encoding/xml"
 	"errors"
 	"fmt"
@@ -14,6 +15,7 @@ import (
 	"io"
 	"os"
 	"os/exec"
+	"reflect"
 	"regexp"
 	"strings"
 )
@@ -24,6 +26,33 @@ const (
 	ColorsDisabled
 )
 
+type ContentType int
+
+const (
+	ContentXml ContentType = iota
+	ContentHtml
+	ContentJson
+	ContentText
+)
+
+type QueryOptions struct {
+	WithTags bool
+	Indent   string
+	Colors   int
+}
+
+const (
+	jsonTokenTopValue = iota
+	jsonTokenArrayStart
+	jsonTokenArrayValue
+	jsonTokenArrayComma
+	jsonTokenObjectStart
+	jsonTokenObjectKey
+	jsonTokenObjectColon
+	jsonTokenObjectValue
+	jsonTokenObjectComma
+)
+
 func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) error {
 	decoder := xml.NewDecoder(reader)
 	decoder.Strict = false
@@ -160,8 +189,7 @@ func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) er
 	return nil
 }
 
-func XPathQuery(reader io.Reader, writer io.Writer, query string, singleNode bool, nodeContent bool, indent string,
-	colors int) (errRes error) {
+func XPathQuery(reader io.Reader, writer io.Writer, query string, singleNode bool, options QueryOptions) (errRes error) {
 	defer func() {
 		if err := recover(); err != nil {
 			errRes = errors.New(fmt.Sprintf("XPath error: %v", err))
@@ -179,11 +207,11 @@ func XPathQuery(reader io.Reader, writer io.Writer, query string, singleNode boo
 
 	if singleNode {
 		if n := xmlquery.FindOne(doc, query); n != nil {
-			return printNodeContent(writer, n, nodeContent, indent, colors)
+			return printNodeContent(writer, n, options)
 		}
 	} else {
 		for _, n := range xmlquery.Find(doc, query) {
-			err := printNodeContent(writer, n, nodeContent, indent, colors)
+			err := printNodeContent(writer, n, options)
 			if err != nil {
 				return err
 			}
@@ -193,24 +221,45 @@ func XPathQuery(reader io.Reader, writer io.Writer, query string, singleNode boo
 	return nil
 }
 
-func printNodeContent(writer io.Writer, node *xmlquery.Node, withTags bool, indent string, colors int) error {
-	if withTags {
+func printNodeContent(writer io.Writer, node *xmlquery.Node, options QueryOptions) error {
+	if options.WithTags {
 		reader := strings.NewReader(node.OutputXML(true))
-		return FormatXml(reader, writer, indent, colors)
+		return FormatXml(reader, writer, options.Indent, options.Colors)
 	}
 
 	_, err := fmt.Fprintf(writer, "%s\n", strings.TrimSpace(node.InnerText()))
 	return err
 }
 
-func CSSQuery(reader io.Reader, writer io.Writer, query string) error {
+func CSSQuery(reader io.Reader, writer io.Writer, query string, attr string, options QueryOptions) error {
 	doc, err := goquery.NewDocumentFromReader(reader)
 	if err != nil {
 		return err
 	}
 
 	doc.Find(query).Each(func(index int, item *goquery.Selection) {
-		_, _ = fmt.Fprintf(writer, "%s\n", strings.TrimSpace(item.Text()))
+		if attr != "" {
+			_, _ = fmt.Fprintf(writer, "%s\n", strings.TrimSpace(item.AttrOr(attr, "")))
+		} else {
+			if options.WithTags {
+				node := item.Nodes[0]
+				tagName := node.Data
+				var attrs []string
+				attrsStr := ""
+				for _, tagAttr := range node.Attr {
+					escapedValue, _ := escapeText(string(tagAttr.Val))
+					attrs = append(attrs, string(tagAttr.Key)+"=\""+escapedValue+"\"")
+				}
+				if len(attrs) > 0 {
+					attrsStr = " " + strings.Join(attrs, " ")
+				}
+				html, _ := item.Html()
+				reader := strings.NewReader(fmt.Sprintf("<%s%s>%s</%s>", tagName, attrsStr, html, tagName))
+				FormatHtml(reader, writer, options.Indent, options.Colors)
+			} else {
+				_, _ = fmt.Fprintf(writer, "%s\n", strings.TrimSpace(item.Text()))
+			}
+		}
 	})
 
 	return nil
@@ -318,6 +367,90 @@ func FormatHtml(reader io.Reader, writer io.Writer, indent string, colors int) e
 	return nil
 }
 
+func FormatJson(reader io.Reader, writer io.Writer, indent string, colors int) error {
+	decoder := json.NewDecoder(reader)
+	decoder.UseNumber()
+
+	if ColorsDefault != colors {
+		color.NoColor = colors == ColorsDisabled
+	}
+
+	tagColor := color.New(color.FgYellow).SprintFunc()
+	attrColor := color.New(color.FgHiBlue).SprintFunc()
+	valueColor := color.New(color.FgGreen).SprintFunc()
+
+	level := 0
+	suffix := ""
+	prefix := ""
+
+	for {
+		token, err := decoder.Token()
+
+		if err == io.EOF {
+			break
+		}
+
+		if err != nil {
+			return err
+		}
+
+		v := reflect.ValueOf(*decoder)
+		tokenState := v.FieldByName("tokenState").Int()
+
+		switch tokenState {
+		case jsonTokenObjectColon:
+			suffix = ": "
+		case jsonTokenObjectComma:
+			suffix = ",\n" + strings.Repeat(indent, level)
+		case jsonTokenArrayComma:
+			suffix = ",\n" + strings.Repeat(indent, level)
+		}
+
+		switch tokenType := token.(type) {
+		case json.Delim:
+			switch rune(tokenType) {
+			case '{':
+				_, _ = fmt.Fprintf(writer, "%s%s\n", prefix, tagColor("{"))
+				level++
+				suffix = strings.Repeat(indent, level)
+			case '}':
+				level--
+				_, _ = fmt.Fprintf(writer, "\n%s%s", strings.Repeat(indent, level), tagColor("}"))
+				if tokenState == jsonTokenArrayComma {
+					suffix = ",\n" + strings.Repeat(indent, level)
+				}
+			case '[':
+				_, _ = fmt.Fprintf(writer, "%s%s\n", prefix, tagColor("["))
+				level++
+				suffix = strings.Repeat(indent, level)
+			case ']':
+				level--
+				_, _ = fmt.Fprintf(writer, "\n%s%s", strings.Repeat(indent, level), tagColor("]"))
+			}
+		case string:
+			value := valueColor(token)
+			if tokenState == jsonTokenObjectColon {
+				value = attrColor(token)
+			}
+			_, _ = fmt.Fprintf(writer, "%s\"%s\"", prefix, value)
+		case float64:
+			_, _ = fmt.Fprintf(writer, "%s%v", prefix, valueColor(token))
+		case json.Number:
+			_, _ = fmt.Fprintf(writer, "%s%v", prefix, valueColor(token))
+		case bool:
+			_, _ = fmt.Fprintf(writer, "%s%v", prefix, valueColor(token))
+		case nil:
+			_, _ = fmt.Fprintf(writer, "%s%s", prefix, valueColor("null"))
+		}
+
+		prefix = suffix
+	}
+
+	_, _ = fmt.Fprint(writer, "\n")
+
+	return nil
+}
+
 func IsHTML(input string) bool {
 	input = strings.ToLower(input)
 	htmlMarkers := []string{"html", "<!d", "<body"}
@@ -331,6 +464,12 @@ func IsHTML(input string) bool {
 	return false
 }
 
+func IsJSON(input string) bool {
+	input = strings.ToLower(input)
+	matched, _ := regexp.MatchString(`\s*[{\[]`, input)
+	return matched
+}
+
 func PagerPrint(reader io.Reader, writer io.Writer) error {
 	pager := os.Getenv("PAGER")
 
