@@ -2,12 +2,13 @@ package utils
 
 import (
 	"bytes"
-	"github.com/stretchr/testify/assert"
 	"io"
 	"os"
 	"path"
 	"strings"
 	"testing"
+
+	"github.com/stretchr/testify/assert"
 )
 
 func getFileReader(filename string) io.Reader {
@@ -63,9 +64,9 @@ func TestFormatHtml(t *testing.T) {
 	for unformattedFile, expectedFile := range files {
 		unformattedHtmlReader := getFileReader(path.Join("..", "..", "test", "data", "html", unformattedFile))
 
-		bytes, readErr := os.ReadFile(path.Join("..", "..", "test", "data", "html", expectedFile))
+		data, readErr := os.ReadFile(path.Join("..", "..", "test", "data", "html", expectedFile))
 		assert.Nil(t, readErr)
-		expectedHtml := string(bytes)
+		expectedHtml := string(data)
 
 		output := new(strings.Builder)
 		formatErr := FormatHtml(unformattedHtmlReader, output, "  ", ColorsDisabled)
@@ -74,6 +75,25 @@ func TestFormatHtml(t *testing.T) {
 	}
 }
 
+func TestFormatJson(t *testing.T) {
+	files := map[string]string{
+		"unformatted.json": "formatted.json",
+	}
+
+	for unformattedFile, expectedFile := range files {
+		unformattedJsonReader := getFileReader(path.Join("..", "..", "test", "data", "json", unformattedFile))
+
+		data, readErr := os.ReadFile(path.Join("..", "..", "test", "data", "json", expectedFile))
+		assert.Nil(t, readErr)
+		expectedJson := string(data)
+
+		output := new(strings.Builder)
+		formatErr := FormatJson(unformattedJsonReader, output, "  ", ColorsDisabled)
+		assert.Nil(t, formatErr)
+		assert.Equal(t, expectedJson, output.String())
+	}
+}
+
 func TestXPathQuery(t *testing.T) {
 	type test struct {
 		input  string
@@ -91,18 +111,37 @@ func TestXPathQuery(t *testing.T) {
 	for _, testCase := range tests {
 		fileReader := getFileReader(path.Join("..", "..", "test", "data", "xml", testCase.input))
 		output := new(strings.Builder)
-		err := XPathQuery(fileReader, output, testCase.query, true, testCase.node, "  ", 0)
+		options := QueryOptions{WithTags: testCase.node, Indent: "  "}
+		err := XPathQuery(fileReader, output, testCase.query, true, options)
 		assert.Nil(t, err)
 		assert.Equal(t, testCase.result, strings.Trim(output.String(), "\n"))
 	}
 }
 
 func TestCSSQuery(t *testing.T) {
-	fileReader := getFileReader(path.Join("..", "..", "test", "data", "html", "formatted.html"))
-	output := new(strings.Builder)
-	err := CSSQuery(fileReader, output, "body > p")
-	assert.Nil(t, err)
-	assert.Equal(t, "text", strings.Trim(output.String(), "\n"))
+	type test struct {
+		input  string
+		node   bool
+		query  string
+		attr   string
+		result string
+	}
+
+	tests := []test{
+		{input: "formatted.html", node: false, query: "body > p", attr: "", result: "text"},
+		{input: "formatted.html", node: false, query: "script", attr: "src", result: "foo.js\nbar.js\nbaz.js"},
+		{input: "formatted.html", node: true, query: "p", attr: "", result: "<p>text</p>"},
+		{input: "formatted.html", node: true, query: "a", attr: "", result: "<a href=\"https://example.com\">link</a>"},
+	}
+
+	for _, testCase := range tests {
+		fileReader := getFileReader(path.Join("..", "..", "test", "data", "html", testCase.input))
+		output := new(strings.Builder)
+		options := QueryOptions{WithTags: testCase.node, Indent: "  "}
+		err := CSSQuery(fileReader, output, testCase.query, testCase.attr, options)
+		assert.Nil(t, err)
+		assert.Equal(t, testCase.result, strings.Trim(output.String(), "\n"))
+	}
 }
 
 func TestIsHTML(t *testing.T) {
@@ -114,6 +153,14 @@ func TestIsHTML(t *testing.T) {
 	assert.False(t, IsHTML("<root></root>"))
 }
 
+func TestIsJSON(t *testing.T) {
+	assert.True(t, IsJSON(`{"key": "value"}`))
+	assert.True(t, IsJSON(`{"key": "value", "key2": "value2"}`))
+	assert.True(t, IsJSON(`[1, 2, 3]`))
+	assert.True(t, IsJSON(`   {}`))
+	assert.False(t, IsJSON(`<html></html>`))
+}
+
 func TestPagerPrint(t *testing.T) {
 	var output bytes.Buffer
 	fileReader := getFileReader(path.Join("..", "..", "test", "data", "html", "formatted.html"))
